module ABCDtest

using ModelingToolkit, OrdinaryDiffEq
using Latexify

@parameters begin
    R=2.3
    L=6.54e-4
    k_E=9.993E-3
    k_M=984.88E-6
    J=8.95E-6
    T_R=292E-6
    U0=3.4
end

@variables t
@variables omega(t)=0.0
@variables I(t)=0.0
@variables U(t)
@variables tau_Mot(t)
@variables ΔU(t)=0.0 [input = true]

D=Differential(t)

eqs = [
    U ~ U0 + ΔU
    L*D(I) ~ U-I*R-k_E*I*omega
    tau_Mot ~ k_M*I^2
    J*D(omega) ~ tau_Mot-T_R
    ]

@named sys = ODESystem(eqs, t)

inputs = [ΔU]
outputs = [tau_Mot, omega]

LinearSys, simpleSys = ModelingToolkit.linearize_symbolic(sys,inputs,outputs)
a = [:(A=$(LinearSys.A))  :(B=$(LinearSys.B))  :(C=$(LinearSys.C))  :(D=$(LinearSys.D))   ]
a = reshape(a,(4,1))
a = vcat(a,:(input = $(inputs)))
a = vcat(a,:(output = $(outputs)))

render(latexify(a, env=:table),MIME("image/png"), name="ABCDsymbolic2", open=true)

end # module

